Just a regular commit
[backups/.git] / main.cc
diff --git a/main.cc b/main.cc
index dbd96a0c0f56b7fb3b947a3687ff1f43dfe6cb73..8ffd418cc9ec289ae0ab8dc8eaa33dc23ad1ed3c 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -3,9 +3,12 @@
 #include <string>
 #include <vector>
 #include <algorithm>
+#include <set>
 
 #include <sqlite3.h>
 
+#include "filedata.hpp"
+
 using namespace std;
 
 vector<string> split( const string &line, char c, int limit = -1 ) {
@@ -58,19 +61,29 @@ void sql_experimenting() {
 }
 
 int main() {
-//   string file_string;
-//   do {
-//     file_string.clear();
-//     for( int c = cin.get(); 0 != c && ! cin.eof(); c = cin.get() ) {
-//       file_string.push_back( c );
-//     }
-//     if( 0 != file_string.size() ) {
-//       // Example entry
-//       // type perms user group size datemodified name (7 total)
-//       // f 0600 cnb cnb 424 20051015205340 ./.git/index
-//       vector<string> values = split( file_string, ' ', 7 );
-//     }
-//   } while( ! cin.eof() );
+  string file_string;
+  set<FileData*,FileDataPtrCmp> current_files;
+
+  // Parse the list of files on stdin
+  do {
+    file_string.clear();
+    for( int c = cin.get(); 0 != c && ! cin.eof(); c = cin.get() ) {
+      file_string.push_back( c );
+    }
+    if( 0 != file_string.size() ) {
+      // Example entry
+      // type perms user group size datemodified name (7 total)
+      // f 0600 cnb cnb 424 20051015205340 ./.git/index
+      vector<string> vals = split( file_string, ' ', 7 );
+      current_files.insert( new FileData( vals[0][0],
+            vals[1],
+            vals[2],
+            vals[3],
+            atoi( vals[4].c_str() ),
+            atoi( vals[5].c_str() ),
+            vals[6]) );
+    }
+  } while( ! cin.eof() );
 
-  sql_experimenting();
+  set<FileData*,FileDataPtrCmp> previous_files;
 }